from django.conf import settings

ADWARE_TEMPLATE_BASE_DIR = getattr(settings, 'ADWARE_TEMPLATE_BASE_DIR', 'ads')
ADWARE_MINIMUM_IMPRESSION_PERCENTAGE = getattr(settings, 'ADWARE_MINIMUM_IMPRESSION_PERCENTAGE', 30)

ADWARE_DEFAULT_AD_CLIENT = getattr(settings, 'ADWARE_DEFAULT_AD_CLIENT', '')
ADWARE_DEFAULT_AD_SLOT = getattr(settings, 'ADWARE_DEFAULT_AD_SLOT', '')

ADWARE_IMPRESSION_REWARD_ENABLED = getattr(settings, 'ADWARE_IMPRESSION_REWARD_ENABLED', True)
ADWARE_IMPRESSION_REWARD = [[20000, 50], [15000, 40], [10000, 30], [5000, 20], [1000, 10]]  # Must be in reverse order
ADWARE_MAX_PERCENTAGE_REWARD = 80
