# -*- coding: utf-8 -*-
# Generated by Django 1.9.4 on 2016-03-25 15:53
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('adware', '0002_auto_20160324_2006'),
    ]

    operations = [
        migrations.AlterField(
            model_name='adsense',
            name='active',
            field=models.BooleanField(default=True, help_text='Active shows your ads.', verbose_name='active'),
        ),
    ]
