# -*- coding: utf-8 -*-
# Generated by Django 1.9.2 on 2016-03-24 23:03
from __future__ import unicode_literals

from django.conf import settings
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='AdSense',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('code', models.TextField(blank=True, help_text='Your Google "Responsive" Adsense Code.', null=True, verbose_name='Adsense')),
                ('ad_client', models.CharField(blank=True, max_length=60, null=True)),
                ('ad_slot', models.CharField(blank=True, max_length=50, null=True)),
                ('percentage', models.PositiveIntegerField(default=30, help_text='Ad impression percentage (1-100).', validators=[django.core.validators.MinValueValidator(1), django.core.validators.MaxValueValidator(100)])),
                ('is_active', models.BooleanField(default=True, help_text='Inactive ads will not be shown.', verbose_name='active')),
                ('user', models.OneToOneField(editable=False, on_delete=django.db.models.deletion.CASCADE, related_name='adsense', to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
