# -*- coding: utf-8 -*-
# Generated by Django 1.9.2 on 2016-03-25 00:06
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('adware', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='adsense',
            name='is_active',
        ),
        migrations.AddField(
            model_name='adsense',
            name='active',
            field=models.BooleanField(default=True, help_text='Active to show your ads.', verbose_name='active'),
        ),
        migrations.AddField(
            model_name='adsense',
            name='suspended',
            field=models.BooleanField(default=False, help_text='Suspended AdShare will not show ads. For admin use.', verbose_name='suspended'),
        ),
        migrations.AlterField(
            model_name='adsense',
            name='code',
            field=models.TextField(blank=True, help_text='Your Google "Responsive" Adsense Code.', null=True, verbose_name='Adsense Code'),
        ),
    ]
